# pycommons-collections

[![PyPI](https://img.shields.io/pypi/v/pycommons-collections)](https://pypi.org/project/pycommons-collections/)
![versions](https://img.shields.io/pypi/pyversions/pycommons-collections.svg)
![PyPI - License](https://img.shields.io/pypi/l/pycommons-collections)
![PyPI - Downloads](https://img.shields.io/pypi/dw/pycommons-collections)

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Python Commons Collections package inspired
by [Apache Commons Collections](https://commons.apache.org/proper/commons-collections/)
available in Java.

Visit the [documentation](https://pycommons.github.io/pycommons-collections) to view
the usage of each and every class and feature provided by this library.

## Get Started

To get started with this library, you can install this in your virtual environment
by running

```shell
pip install pycommons-collections
```

With [poetry](https://python-poetry.org/), you can run the following command to add the library to your
project

```shell
poetry add pycommons-collections
```

## License

Apache-2.0 (See [License](LICENSE))

## Author

[Shashank Sharma](https://github.com/shashankrnr32).

